# authentic2-auth-email - authentic2 authentication for Email
# Copyright (C) 2024 Entr'ouvert
#
# This program is free software: you can redistribute it and/or modify it
# under the terms of the GNU Affero General Public License as published
# by the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU Affero General Public License for more details.
#
# You should have received a copy of the GNU Affero General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.

from django.db import models
from django.utils.translation import gettext as _

from authentic2.apps.authenticators.models import BaseAuthenticator


class EmailAuthenticator(BaseAuthenticator):
    _id = 'email'
    type = 'email'
    how = ['email']
    unique = True
    min_required_auth_level = 1

    class Meta:
        verbose_name = _('Email')

    code_size = models.PositiveSmallIntegerField(
        _('Code size'),
        default=6,
        help_text=_('Number of digits used for each code'),
    )

    @property
    def manager_form_classes(self):
        from .forms import EmailAuthenticatorForm

        return [
            (_('General'), EmailAuthenticatorForm),
        ]

    # INFO: 3 magic methods called by `utils_misc.get_authenticator_method`.
    #       They depend on the views… that depend on the model…
    #       That’s why the import are within the methods.
    def login(self, request, *args, **kwargs):
        from .views import login

        return login(request, *args, **kwargs)

    def profile(self, request, *args, **kwargs):
        from .views import profile

        return profile(request, *args, **kwargs)

    def registration(self, request, *args, **kwargs):
        raise NotImplementedError()
