# authentic2-auth-rc - authentic2 authentication for RecoveryCodes
# Copyright (C) 2024 Entr'ouvert
#
# This program is free software: you can redistribute it and/or modify it
# under the terms of the GNU Affero General Public License as published
# by the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU Affero General Public License for more details.
#
# You should have received a copy of the GNU Affero General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.

from django import forms
from django.core.exceptions import ValidationError
from django.utils.translation import gettext as _

from .models import RecoveryCodeAuthenticator


def validate_required_auth_level(value):
    if int(value) < RecoveryCodeAuthenticator.min_required_auth_level:
        raise ValidationError(
            _('The required auth level cannot be below {level}.').format(
                level=RecoveryCodeAuthenticator.min_required_auth_level
            ),
        )


class RecoveryCodeAuthenticatorForm(forms.ModelForm):
    class Meta:
        model = RecoveryCodeAuthenticator
        exclude = []

    required_auth_level = forms.IntegerField(
        validators=[validate_required_auth_level],
        label=_('Required authentication level'),
    )


class EnableForm(forms.Form):
    pass


class LoginForm(forms.Form):
    recovery_code = forms.CharField(
        max_length=10,
        min_length=10,
        label=_('Recovery code'),
        help_text=_(
            'Use one of your recovery code. Remember these are for one-time '
            "use, hence the code you choose won't be valid next time."
        ),
    )
