# authentic2-auth-totp - authentic2 authentication for TOTP
# Copyright (C) 2024 Entr'ouvert
#
# This program is free software: you can redistribute it and/or modify it
# under the terms of the GNU Affero General Public License as published
# by the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU Affero General Public License for more details.
#
# You should have received a copy of the GNU Affero General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.

from django import forms
from django.core.exceptions import ValidationError
from django.utils.translation import gettext as _

from .models import TOTPAuthenticator


def validate_number(value):
    try:
        int(value)
    except ValueError:
        raise ValidationError(
            _('Code must be a number.'),
        )


def validate_required_auth_level(value):
    if int(value) < TOTPAuthenticator.min_required_auth_level:
        raise ValidationError(
            _('The required auth level cannot be below {level}.').format(
                level=TOTPAuthenticator.min_required_auth_level
            ),
        )


class TOTPAuthenticatorForm(forms.ModelForm):
    class Meta:
        model = TOTPAuthenticator
        exclude = []

    required_auth_level = forms.IntegerField(
        validators=[validate_required_auth_level],
        label=_('Required authentication level'),
    )


class EnableForm(forms.Form):
    one_time_password = forms.CharField(
        max_length=6,
        min_length=6,
        validators=[validate_number],
        label=_('One-Time Password'),
    )


class LoginForm(EnableForm):
    def __init__(self, *args, **kwargs):
        super().__init__(*args, **kwargs)
        self.fields['one_time_password'].help_text = _(
            'In order to be granted access, you must enter the six-digit '
            'code given by the authentificator app on your device.'
        )
