# authentic2-auth-totp - authentic2 authentication for TOTP
# Copyright (C) 2024 Entr'ouvert
#
# This program is free software: you can redistribute it and/or modify it
# under the terms of the GNU Affero General Public License as published
# by the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU Affero General Public License for more details.
#
# You should have received a copy of the GNU Affero General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.

from django.conf import settings
from django.db import models
from django.utils.translation import gettext as _

from authentic2.apps.authenticators.models import BaseAuthenticator


class TOTPAuthenticator(BaseAuthenticator):
    _id = 'totp'
    type = 'totp'
    how = ['totp']
    unique = True
    min_required_auth_level = 1

    class Meta:
        verbose_name = _('One-time password')

    @property
    def manager_form_classes(self):
        from .forms import TOTPAuthenticatorForm

        return [
            (_('General'), TOTPAuthenticatorForm),
        ]

    # INFO: 3 magic methods called by `utils_misc.get_authenticator_method`.
    #       They depend on the views… that depend on the model…
    #       That’s why the import are within the methods.
    def login(self, request, *args, **kwargs):
        from .views import login

        return login(request, *args, **kwargs)

    def profile(self, request, *args, **kwargs):
        from .views import profile

        return profile(request, *args, **kwargs)

    def registration(self, request, *args, **kwargs):
        raise NotImplementedError()


class TOTPSecret(models.Model):
    user = models.OneToOneField(
        settings.AUTH_USER_MODEL,
        primary_key=True,
        related_name='totp_secret',
        verbose_name=_('user'),
        on_delete=models.CASCADE,
    )
    key = models.CharField(max_length=32)
