# authentic2-auth-totp - authentic2 authentication for TOTP
# Copyright (C) 2024 Entr'ouvert
#
# This program is free software: you can redistribute it and/or modify it
# under the terms of the GNU Affero General Public License as published
# by the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU Affero General Public License for more details.
#
# You should have received a copy of the GNU Affero General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.

from base64 import b64encode
from io import BytesIO

import pyotp
from qrcode import QRCode


def make_qrcode(user, secret=None):
    account = user.get_full_name().encode('utf-8')
    totp = pyotp.TOTP(secret.key if secret else user.totp_secret.key)
    # TODO: use dynamic app name instead of Publik
    uri = totp.provisioning_uri(name=account, issuer_name='Publik')
    qr = QRCode(box_size=5)
    qr.add_data(uri)
    qr.make(fit=True)
    img = qr.make_image()
    img_bytes = BytesIO()
    img.save(img_bytes, format='png')
    uri = b64encode(img_bytes.getvalue())
    return uri
